.. sam documentation master file, created by
   sphinx-quickstart on Tue Dec 18 13:40:42 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to SAM's documentation!
===============================

.. include:: intro.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   data
   examples
   data_sources
   datasets
   preprocessing
   exploration
   feature_engineering
   metrics
   models
   visualization
   validation
   utils


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
